@@ -5,16 +5,16 @@
 
 """
 # excel
-import openpyxl
-from openpyxl import load_workbook, Workbook
-from openpyxl.styles import PatternFill, Border, Side, Alignment, Protection
-from openpyxl.styles import Font, colors, Color
-from openpyxl.utils.cell import coordinate_from_string, column_index_from_string
+# import openpyxl
+# from openpyxl import load_workbook, Workbook
+# from openpyxl.styles import PatternFill, Border, Side, Alignment, Protection
+# from openpyxl.styles import Font, colors, Color
+# from openpyxl.utils.cell import coordinate_from_string, column_index_from_string
 #
 import numpy as np
-import matplotlib
-import matplotlib.pyplot as plt
-import math
+from openpyxl.styles.borders import Border, Side
+from openpyxl.drawing.image import Image
+from openpyxl.styles import Protection
 import sys
 # from xt import thesame
 
@@ -591,7 +591,7 @@ class Xcel:
             print("Failed to save "+filename)
             return False
     def addimage(self, picfile, row, column=1):
-        img=openpyxl.drawing.image.Image(picfile)
+        img=Image(picfile)
         img.anchor(self.ws.cell(row=row, column=column)) # upper right corner of the image
         self.ws.add_image(img)
 
